cd here, then run
pip install .

Then you can open your command line and run
clipform

Follow the prompts.
Currently, it assumes your input to be a '/r/n' separated list and will return it quoted and ',/r/n' separated.
As in

A
B
C

returns 

'A',
'B',
'C'